Asphalt-serialization documentation
===================================

Asphalt-serialization provides support for serializing Python objects to bytestrings and
deserializing bytestrings back to Python objects.

.. toctree::
   :maxdepth: 1

   configuration
   usage
   extending
   versionhistory


Indices and tables
==================

* :ref:`API reference <modindex>`
